pub fn error_response(status: StatusCode, message: String) -> ResponseExpand description
error_response is a helper function to build a response with status code and message.
pub fn error_response(status: StatusCode, message: String) -> Responseerror_response is a helper function to build a response with status code and message.